@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{Astro::Coord::ECI::TLE};
 
-our $VERSION = '0.098_04';
+our $VERSION = '0.098_05';
 
 use Astro::Coord::ECI::Sun;
 use Astro::Coord::ECI::Utils qw{:all};
@@ -1688,7 +1688,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Wed Jun 27 15:31:14 2018 GMT
+# on Thu Jun 28 12:28:04 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1728,7 +1728,7 @@ __PACKAGE__->status( add => 24967, iridium => '-', 'Iridium 36', 'Tumbling' );
 __PACKAGE__->status( add => 24968, iridium => 'D', 'Iridium 37', 'Decayed 2018-05-26' );
 __PACKAGE__->status( add => 24969, iridium => 'D', 'Iridium 34', 'Decayed 2018-01-08' );
 __PACKAGE__->status( add => 25039, iridium => 'D', 'Iridium 43', 'Decayed 2018-02-11' );
-__PACKAGE__->status( add => 25040, iridium => 'S', 'Iridium 41', '' );
+__PACKAGE__->status( add => 25040, iridium => '-', 'Iridium 41', 'Tumbling' );
 __PACKAGE__->status( add => 25041, iridium => '-', 'Iridium 40', 'Tumbling' );
 __PACKAGE__->status( add => 25042, iridium => '-', 'Iridium 39', 'Tumbling' );
 __PACKAGE__->status( add => 25043, iridium => '-', 'Iridium 38', 'Tumbling' );
@@ -1791,8 +1791,8 @@ __PACKAGE__->status( add => 27451, iridium => '+', 'Iridium 98', '' );
 
 # Summary:
 # Operational [+]: 19
-#       Spare [S]: 17
-#    Tumbling [-]: 38
+#       Spare [S]: 16
+#    Tumbling [-]: 39
 #     Decayed [D]: 23
 
 1;
